@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Mapping, Sequence
+from typing import Dict, List, Mapping, Sequence
 
 from .literals import EnvironmentStatusType, FederationModeType
 
@@ -35,6 +35,7 @@ __all__ = (
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ResponseMetadataTypeDef",
+    "SuperuserParametersTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateEnvironmentRequestRequestTypeDef",
@@ -55,6 +56,8 @@ _OptionalCreateEnvironmentRequestRequestTypeDef = TypedDict(
         "tags": Mapping[str, str],
         "federationMode": FederationModeType,
         "federationParameters": "FederationParametersTypeDef",
+        "superuserParameters": "SuperuserParametersTypeDef",
+        "dataBundles": Sequence[str],
     },
     total=False,
 )
@@ -169,11 +172,20 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
 
+SuperuserParametersTypeDef = TypedDict(
+    "SuperuserParametersTypeDef",
+    {
+        "emailAddress": str,
+        "firstName": str,
+        "lastName": str,
+    },
+)
+
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
